@@ -43,7 +43,7 @@ class CampaignManager:
                 if ext not in [".rdy", ".sqlite"]:
                     continue
                 else:
-                    self.files.append(RDYFile())
+                    self.files.append(RDYFile(file_path))
 
         else:
             raise TypeError("folder argument must be list or str")
